"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const plugin_helpers_1 = require("@graphql-codegen/plugin-helpers");
const path_1 = require("path");
// Actually this should go to ardatan/graphql-toolkit
function printSchemaWithDirectives(schema) {
    const allTypes = schema.getTypeMap();
    const allTypesAst = Object.keys(allTypes).map(key => allTypes[key].astNode);
    const allDirectivesAst = schema.getDirectives().map(dir => dir.astNode);
    return [...allDirectivesAst, ...allTypesAst].map(ast => graphql_1.print(ast)).join('\n');
}
exports.printSchemaWithDirectives = printSchemaWithDirectives;
exports.plugin = async (schema, _documents, { includeDirectives = false, federation }) => {
    const outputSchema = federation
        ? plugin_helpers_1.removeFederation(schema, {
            withDirectives: includeDirectives,
        })
        : schema;
    if (includeDirectives) {
        return printSchemaWithDirectives(outputSchema);
    }
    return graphql_1.printSchema(outputSchema, { commentDescriptions: false });
};
exports.validate = async (_schema, _documents, _config, outputFile, allPlugins) => {
    const singlePlugin = allPlugins.length === 1;
    if (singlePlugin && path_1.extname(outputFile) !== '.graphql') {
        throw new Error(`Plugin "schema-ast" requires extension to be ".graphql"!`);
    }
};
//# sourceMappingURL=index.js.map