import { printSchema, print } from 'graphql';
import { removeFederation } from '@graphql-codegen/plugin-helpers';
import { extname } from 'path';
// Actually this should go to ardatan/graphql-toolkit
export function printSchemaWithDirectives(schema) {
    const allTypes = schema.getTypeMap();
    const allTypesAst = Object.keys(allTypes).map(key => allTypes[key].astNode);
    const allDirectivesAst = schema.getDirectives().map(dir => dir.astNode);
    return [...allDirectivesAst, ...allTypesAst].map(ast => print(ast)).join('\n');
}
export const plugin = async (schema, _documents, { includeDirectives = false, federation }) => {
    const outputSchema = federation
        ? removeFederation(schema, {
            withDirectives: includeDirectives,
        })
        : schema;
    if (includeDirectives) {
        return printSchemaWithDirectives(outputSchema);
    }
    return printSchema(outputSchema, { commentDescriptions: false });
};
export const validate = async (_schema, _documents, _config, outputFile, allPlugins) => {
    const singlePlugin = allPlugins.length === 1;
    if (singlePlugin && extname(outputFile) !== '.graphql') {
        throw new Error(`Plugin "schema-ast" requires extension to be ".graphql"!`);
    }
};
//# sourceMappingURL=index.js.map